summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_freebsd.sh
diff options
context:
space:
mode:
Diffstat (limited to 'bin/reproducible_freebsd.sh')
-rwxr-xr-xbin/reproducible_freebsd.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_freebsd.sh b/bin/reproducible_freebsd.sh
index 5f08ce59..b4d90df8 100755
--- a/bin/reproducible_freebsd.sh
+++ b/bin/reproducible_freebsd.sh
@@ -111,7 +111,7 @@ umask 0022
# cleanup on the node
$RSSH 'sudo rm -r /usr/src /usr/obj'
# run debbindiff on the results
TIMEOUT="30m"
DBDSUITE="unstable"
DBDVERSION="$(schroot --directory /tmp -c source:jenkins-reproducible-${DBDSUITE}-debbindiff debbindiff -- --version 2>&1)"
@@ -131,7 +131,7 @@ for i in * ; do
echo " <table><tr><th>Release files for <code>$i</code></th></tr>" >> $FILES_HTML
for j in $(find * -type f |sort -u ) ; do
let ALL_FILES+=1
- call_debbindiff $i $j
+ call_diffoscope $i $j
get_filesize $j
if [ -f $TMPDIR/$i/$j.html ] ; then
mkdir -p $BASE/freebsd/dbd/$i/$(dirname $j)
@@ -111,7 +111,7 @@ umask 0022
# cleanup on the node
$RSSH 'sudo rm -r /usr/src /usr/obj'
-# run debbindiff on the results
+# run diffoscope on the results
TIMEOUT="30m"
DBDSUITE="unstable"